@@ -14,10 +14,22 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.2.8'
+__version__ = '0.2.9'
 
-__all__ = ['ANY_ARGUMENT',
-           'ANY_ARGUMENTS',
+__all__ = ['ANY_BOOLEAN',
+           'ANY_DICTIONARY',
+           'ANY_FILE',
+           'ANY_FLOAT',
+           'ANY_INTEGER',
+           'ANY_LIST',
+           'ANY_LONG',
+           'ANY_SLICE',
+           'ANY_STRING',
+           'ANY_TUPLE',
+           'ANY_UNICODE',
+           'ANY_VALUE',
+           'ANY_VALUES',
+           'ANY_XRANGE',
            'AT_LEAST_ONCE',
            'NEVER',
            'UnitTests',
@@ -46,15 +58,29 @@ from fluentmock.exceptions import (FoundMatcherInNativeVerificationError,
                                    VerificationError)
 from fluentmock.matchers import (AtLeastOnceMatcher,
                                  FluentMatcher,
-                                 FluentAnyArguments,
-                                 FluentAnyArgument,
+                                 AnyValuesMatcher,
+                                 AnyValueMatcher,
+                                 AnyValueOfTypeMatcher,
                                  NeverMatcher,
                                  TimesMatcher)
 
 LOGGER = getLogger(__name__)
 
-ANY_ARGUMENT = FluentAnyArgument()
-ANY_ARGUMENTS = FluentAnyArguments()
+ANY_BOOLEAN = AnyValueOfTypeMatcher(bool)
+ANY_DICTIONARY = AnyValueOfTypeMatcher(dict)
+ANY_FILE = AnyValueOfTypeMatcher(file)
+ANY_FLOAT = AnyValueOfTypeMatcher(float)
+ANY_INTEGER = AnyValueOfTypeMatcher(int)
+ANY_LIST = AnyValueOfTypeMatcher(list)
+ANY_LONG = AnyValueOfTypeMatcher(long)
+ANY_SLICE = AnyValueOfTypeMatcher(slice)
+ANY_STRING = AnyValueOfTypeMatcher(str)
+ANY_TUPLE = AnyValueOfTypeMatcher(tuple)
+ANY_UNICODE = AnyValueOfTypeMatcher(unicode)
+ANY_VALUE = AnyValueMatcher()
+ANY_VALUES = AnyValuesMatcher()
+ANY_XRANGE = AnyValueOfTypeMatcher(xrange)
+
 AT_LEAST_ONCE = AtLeastOnceMatcher()
 NEVER = NeverMatcher()
 
@@ -122,10 +148,10 @@ class FluentCallEntry(object):
         if not self.target.is_equal_to(target, attribute_name):
             return False
 
-        if self.arguments and self.arguments[0] is ANY_ARGUMENTS:
+        if self.arguments and self.arguments[0] is ANY_VALUES:
             return True
 
-        if arguments and arguments[0] is ANY_ARGUMENTS:
+        if arguments and arguments[0] is ANY_VALUES:
             return True
 
         if self.arguments == arguments and self.keyword_arguments == keyword_arguments:
@@ -259,7 +285,7 @@ class FluentMockConfigurator(object):
         self._fluent_mock = fluent_mock
 
     def __call__(self, *arguments, **keyword_arguments):
-        if len(arguments) > 1 and ANY_ARGUMENTS in arguments:
+        if len(arguments) > 1 and ANY_VALUES in arguments:
             raise InvalidUseOfAnyArgumentsError()
 
         answer = FluentAnswer(self._fluent_mock.object, self._fluent_mock.attribute_name, arguments, keyword_arguments)
@@ -337,7 +363,7 @@ class Verifier(FluentTarget):
         return matching_call_entries
 
     def _ensure_valid_usage_of_any_arguments(self, arguments):
-        if arguments and ANY_ARGUMENTS in arguments:
+        if arguments and ANY_VALUES in arguments:
             if len(arguments) > 1:
                 raise InvalidUseOfAnyArgumentsError()
 
